@@ -43,13 +43,17 @@ class FilterState:
         self.state_store.add('RESET')
 
         self.state = self.state_store.state
+        self.elements = self.state_store.elements
         self.put = self.state_store.put
+        self.mask = self.state_store.mask
+        self.name = self.state_store.name
         self.set = self.state_store.set
         self.next = self.state_store.next
         self.move = self.state_store.move
         self.unset = self.state_store.unset
         self.peek = self.state_store.peek
         self.from_name = self.state_store.from_name
+        self.list = self.state_store.list
         self.state_store.sync()
         self.all = self.state_store.all
         self.started = False
@@ -93,6 +97,7 @@ class FilterState:
             if self.scan != None:
                 ks = self.scan()
                 for v in ks: #os.listdir(self.scan_path):
+                    logg.debug('ks {}'.format(v))
                     k = None
                     try:
                         k = self.state_store.from_elements(v)
